INSPIRATIONAL_QUOTES = [
    {"quote": "Bitterness is like cancer. It eats upon the host.", "author": "Maya Angelou"},
    {"quote": "The true test of character is not how much we know how to do, but how we behave when we don’t know what to do.", "author": "John Holt"},
    {"quote": "It's better to be at the bottom of a ladder you want to climb than halfway up one you don't.", "author": "Stephen Kellogg"},
    {"quote": "The biggest temptation is to settle for too little.", "author": "Thomas Merton"},
    {"quote": "Everybody wants to be famous, but nobody wants to do the work. I live by that. You grind hard so you can play hard. At the end of the day, you put all the work in, and eventually it’ll pay off. It could be in a year, it could be in 30 years. Eventually, your hard work will pay off.", "author": "Kevin Hart"},
    {"quote": "Every action you take is a vote for the type of person you wish to become.", "author": "James Clear"},
    {"quote": "You pray for the hungry. Then you feed them. That’s how prayer works.", "author": "Pope Francis"},
    {"quote": "I would like to show the world today as an ant sees it, and tomorrow as the moon sees it.", "author": "Hannah Höch"},
    {"quote": "Write this down, young man. Life has been extremely, I say extremely, kind.", "author": "Margaret Gorman"},
    {"quote": "What you are, you are by accident of birth; what I am, I am by myself.", "author": "Ludwig van Beethoven"},
    {"quote": "Never allow a person to tell you no who doesn’t have the power to say yes.", "author": "Eleanor Roosevelt"},
    {"quote": "When I hear somebody sigh, 'Life is hard,' I am always tempted to ask, 'Compared to what?'", "author": "Sydney J. Harris"},
    {"quote": "If you do every job like you’re going to do it for the rest of your life, that’s when you get noticed.", "author": "Mary Barra"},
    {"quote": "Anyone who has spent any time in space will love it for the rest of their lives. I achieved my childhood dream of the sky.", "author": "Valentina Tereshkova"},
    {"quote": "Your messaging should convey, 'Here’s why you would be so lucky if you got me,' instead of 'I really wanted it,' which we all tend to do.", "author": "Barbara Corcoran"},
    {"quote": "All medicine is like that. It came from someone who dared.", "author": "Dr. William DeVries"},
    {"quote": "The American city should be a collection of communities where every member has a right to belong. It should be a place where every man feels safe on his streets and in the house of his friends.", "author": "Lyndon B. Johnson"},
    {"quote": "I knew all the rules but the rules did not know me.", "author": "Eddie Vedder"},
    {"quote": "It was the first evidence to me that we’d changed the world.", "author": "John Shepherd-Barron"},
    {"quote": "The things that scare you only make you better and stronger.", "author": "Octavia Spencer"},
    {"quote": "The more I want to get something done, the less I call it work.", "author": "Richard Bach"},
    {"quote": "It's a hard, lonely feeling, to be completely yourself in front of strangers.", "author": "Michael Che"},
    {"quote": "The first step is clearly defining what it is you’re after, because without knowing that, you’ll never get it.", "author": "Halle Berry"},
    {"quote": "Take the opportunity to learn from your mistakes: find the cause of your problem and eliminate it. Don’t try to be perfect; just be an excellent example of being human.", "author": "Tony Robbins"},
    {"quote": "I'm not the next Usain Bolt or Michael Phelps … I'm the first Simone Biles.", "author": "Simone Biles"},
    {"quote": "My mother thinks I am the best. And I was raised to always believe what my mother tells me.", "author": "Diego Maradona"},
    {"quote": "You would be amazed what the ordinary guy knows.", "author": "Matt Drudge"},
    {"quote": "You are never too good for anything. Always be willing to do everything.", "author": "Thomas Parkinson"},
    {"quote": "Do as much homework as you can. Learn everybody’s job and don’t just settle.", "author": "Michael B. Jordan"},
    {"quote": "Those who don’t believe in magic will never find it.", "author": "Roald Dahl"},
    {"quote": "There is no such thing as accident; it is fate misnamed.", "author": "Napoleon Bonaparte"},
    {"quote": "The function of leadership is to produce more leaders, not more followers.", "author": "Ralph Nader"},
    {"quote": "You can overcome anything, if and only if you love something enough.", "author": "Lionel Messi"},
    {"quote": "God works a miracle!", "author": "William Bradford"},
    {"quote": "The man who moves a mountain begins by carrying away small stones.", "author": "Confucius"},
    {"quote": "To make others less happy is a crime. To make ourselves unhappy is where all crime starts.", "author": "Roger Ebert"},
    {"quote": "Opportunities multiply as they are seized.", "author": "Sun Tzu"},
    {"quote": "People who think they know everything are a great annoyance to those of us who do.", "author": "Isaac Asimov"},
    {"quote": "Give me a place to stand, and a lever long enough, and I will move the world.", "author": "Archimedes"},
    {"quote": "People will forget what you said, people will forget what you did, but people will never forget how you made them feel.", "author": "Maya Angelou"},
    {"quote": "I am not afraid of an army of lions led by a sheep; I am afraid of an army of sheep led by a lion.", "author": "Alexander the Great"},
    {"quote": "We're born alone. We do need each other. It's lonely to really effectively live your life, and anyone you can get help from or give help to, that's part of your obligation.", "author": "Bill Murray"},
    {"quote": "Failure is a badge of honor. It means you risked failure. And if you don’t risk failure, you’re never going to do anything that’s different from what you’ve already done or what somebody else has done.", "author": "Charlie Kaufman"},
    {"quote": "This is not just a job. This is a passion. Connecting people, connecting the world, making a difference. How many jobs can say I made the world better today? We do that every single day.", "author": "Ed Bastian"},
    {"quote": "A delayed game is eventually good, but a rushed game is forever bad.", "author": "Shigeru Miyamoto"},
    {"quote": "It's a gift to exist, and with existence comes suffering. There's no escaping that.", "author": "Stephen Colbert"},
    {"quote": "I believe ambition is not a dirty word. It's just believing in yourself and your abilities. Imagine this: What would happen if we were all brave enough to be a little bit more ambitious? I think the world would change.", "author": "Reese Witherspoon"},
    {"quote": "Certain things in life are more important than the usual crap that everyone strives for.", "author": "James Taylor"},
    {"quote": "Logic will get you from A to B. Imagination will take you everywhere.", "author": "Albert Einstein"},
    {"quote": "If you feel safe in the area you’re working in, you’re not working in the right area. Always go a little further into the water than you feel you’re capable of being in. Go a little bit out of your depth. And when you don’t feel that your feet are quite touching the bottom, you’re just about in the right place to do something exciting.", "author": "David Bowie"},
    {"quote": "If you can't fail, you can never get better.", "author": "Benedict Cumberbatch"},
    {"quote": "It took me a long time not to judge myself through someone else’s eyes.", "author": "Sally Field"},
    {"quote": "The best protection any woman can have … is courage.", "author": "Elizabeth Cady Stanton"},
    {"quote": "I have captured the light and arrested its flight. The sun itself shall draw my pictures.", "author": "Louis Daguerre"},
    {"quote": "It's beautiful when you watch something good happen to somebody when it's well deserved.", "author": "Jennifer Lawrence"},
    {"quote": "You can't teach anybody anything, only make them realize the answers are already inside them.", "author": "Galileo Galilei"},
    {"quote": "Talk sense to a fool and he calls you foolish.", "author": "Euripides"},
    {"quote": "If you love what you do and are willing to do what it takes, it’s within your reach.", "author": "Steve Wozniak"},
    {"quote": "Troubles are often the tools by which God fashions us for better things.", "author": "Henry Ward Beecher"},
    {"quote": "To love means loving the unlovable. To forgive means pardoning the unpardonable. Faith means believing the unbelievable. Hope means hoping when everything seems hopeless.", "author": "Gilbert K. Chesterton"},
    {"quote": "The world promises you comfort, but you were not made for comfort. You were made for greatness.", "author": "Pope Benedict XVI"},
    {"quote": "Memory is original events combined with every other time you’ve remembered that event. This is why therapy’s helpful.", "author": "Becky Kennedy"},
    {"quote": "If opportunity doesn’t knock, build a door.", "author": "Milton Berle"},
    {"quote": "It's easy to fool the eye but it's hard to fool the heart.", "author": "Al Pacino"},
    {"quote": "It is not the strongest of the species that survive, nor the most intelligent, but the one most responsive to change.", "author": "Charles Darwin"},
    {"quote": "Success is getting what you want. Happiness is wanting what you get.", "author": "Dale Carnegie"},
    {"quote": "You are on the eve of a complete victory. You can’t go wrong. The world is behind you.", "author": "Josephine Baker"},
    {"quote": "Holding on to anger is like grasping a hot coal with the intent of throwing it at someone else; you are the one who gets burned.", "author": "Buddha"},
    {"quote": "Criticism is something we can avoid easily by saying nothing, doing nothing, and being nothing.", "author": "Aristotle"},
    {"quote": "Don’t let what you don’t know scare you, because it can become your greatest asset. And if you do things without knowing how they have always been done, you’re guaranteed to do them differently.", "author": "Sara Blakely"},
    {"quote": "An innovation will get traction only if it helps people get something that they’re already doing in their lives done better.", "author": "Clayton Christensen"},
    {"quote": "Nursing encompasses an art, a humanistic orientation, a feeling for the value of the individual, and an intuitive sense of ethics, and of the appropriateness of action taken.", "author": "Myrtle Aydelotte"},
    {"quote": "It seems to me that to be peaceful and content, you don’t have to know precisely what you want. It may even be better if you don’t. But I think you do need to be very clear what you DON’T want, and steadfast in the not-doing of those things.", "author": "Sandra Boynton"},
    {"quote": "It was the ultimate dream. But the idea of a young black American like me owning a Cadillac? It seemed too far-fetched.", "author": "Dick Gidron"},
    {"quote": "You are a Universe of Universes and your Soul a source of Songs.", "author": "Rubén Darío"},
    {"quote": "Don’t live the same year 75 times and call it a life.", "author": "Robin Sharma"},
    {"quote": "If there is no struggle, there is no progress.", "author": "Frederick Douglass"},
    {"quote": "Think about me every now and then, old friend.", "author": "John Lennon"},
    {"quote": "We must never be afraid to go too far, for success lies just beyond.", "author": "Marcel Proust"},
    {"quote": "There is no list of rules. There is one rule. The rule is: There are no rules.", "author": "Shonda Rhimes"},
    {"quote": "I would rather have one article a day of this sort; and these 10 or 20 lines might readily represent a whole day’s hard work in the way of concentrated, intense thinking and revision, polish of style, weighing of words.", "author": "Joseph Pulitzer"},
    {"quote": "Winners are the ones who really listen to the truth of their hearts.", "author": "Sylvester Stallone"},
    {"quote": "With everything that has happened to you, you can either feel sorry for yourself or treat what has happened as a gift. Everything is either an opportunity to grow or an obstacle to keep you from growing. You get to choose.", "author": "Wayne Dyer"},
    {"quote": "If you’re too rigid in your thinking you may miss some wonderful opportunities for storytelling.", "author": "Vince Gilligan"},
    {"quote": "Education is not the filling of a pail, but the lighting of a fire.", "author": "William Butler Yeats"},
    {"quote": "Before you can make a dream come true, you must first have one.", "author": "Ronald McNair"},
    {"quote": "Business is built on relationships, relationships are built on trust, and the foundation of trust is honesty.", "author": "Stephen Covey"},
    {"quote": "Far better is it to dare mighty things, to win glorious triumphs, even though checkered by failure, than to rank with those poor spirits who neither enjoy much nor suffer much, because they live in a gray twilight that knows not victory nor defeat.", "author": "Theodore Roosevelt"},
    {"quote": "What we do is more important than what we say or what we say we believe.", "author": "bell hooks"},
    {"quote": "Sometimes all you need is 20 seconds of insane courage.", "author": "Benjamin Mee"},
    {"quote": "Be passionate and bold. Always keep learning. You stop doing useful things if you don’t learn.", "author": "Satya Nadella"},
    {"quote": "The chief cause of failure is substituting what you want most for what you want now.", "author": "Zig Ziglar"},
    {"quote": "If you know exactly what you want to be, you need to spend as much time as possible with people who are actually that already.", "author": "Gary Vaynerchuk"},
    {"quote": "You never know what worse luck your bad luck has saved you from.", "author": "Cormac McCarthy"},
    {"quote": "Leadership is the art of getting someone else to do something you want done because he wants to do it.", "author": "Dwight D. Eisenhower"},
    {"quote": "If it wasn’t hard, everyone would do it. It’s the hard that makes it great.", "author": "Tom Hanks"},
    {"quote": "Sometimes your mistakes are your biggest virtues. You learn so much from the mistake. Those things that you think are the worst thing that’s happening to you can somehow turn around and be the greatest opportunity.", "author": "Nicole Kidman"},
    {"quote": "Get into what your kids are into. How miserable would it be to always be anti-popular stuff like 'Ugh, you seriously like Taylor Swift?'", "author": "Joel Willis"},
    {"quote": "Life is not easy for any of us. But what of that? We must have perseverance and, above all, confidence in ourselves. We must believe we are gifted for something and that this thing must be attained.", "author": "Marie Curie"},
    {"quote": "We hold our heads high, despite the price we have paid, because freedom is priceless.", "author": "Lech Wałęsa"},
    {"quote": "It's always better to shock people and change people's expectations than to give them exactly what they think you can do.", "author": "Jonah Hill"},
    {"quote": "I think happiness is overrated. Satisfied, at peace—those would be more realistic goals.", "author": "Brad Pitt"},
    {"quote": "It is not very often that an opportunity comes knocking. But when it does, you’d better be bathed and dressed and ready to answer its call.", "author": "Jyoti Arora"},
    {"quote": "To understand the heart and mind of a person, look not at what he has already achieved, but at what he aspires to do.", "author": "Kahlil Gibran"},
    {"quote": "Diligence is the mother of good luck.", "author": "Benjamin Franklin"},
    {"quote": "The rung of a ladder was never meant to rest upon, but only to hold a man’s foot long enough to enable him to put the other somewhat higher.", "author": "Thomas Huxley"},
    {"quote": "Thousands of candles can be lighted from a single candle. Happiness never decreases by being shared.", "author": "Buddha"},
    {"quote": "It's hard work to make a four-minute program look effortless and elegant.", "author": "Katarina Witt"},
    {"quote": "I would rather five people knew my work and thought it was good work than five million knew me and were indifferent.", "author": "Colin Firth"},
    {"quote": "Someday is not a day of the week.", "author": "Janet Dailey"},
    {"quote": "If everything seems under control, you’re not going fast enough.", "author": "Mario Andretti"},
    {"quote": "An important attribute of success is to be yourself. Never hide what makes you, you.", "author": "Indra Nooyi"},
    {"quote": "What is harder than rock, or softer than water? Yet soft water hollows out hard rock. Persevere.", "author": "Ovid"},
    {"quote": "My pain may be the reason for somebody’s laugh. But my laugh must never be the reason for somebody’s pain.", "author": "Charlie Chaplin"},
    {"quote": "Don’t worry about failure; you only have to be right once.", "author": "Drew Houston"},
    {"quote": "A lot of times, people look at the negative side of what they feel they can’t do. I always look on the positive side of what I can do.", "author": "Chuck Norris"},
    {"quote": "I tend to think you’re fearless when you recognize why you should be scared of things, but do them anyway.", "author": "Christian Bale"},
    {"quote": "Success is built on the foundation of courage, hard work and individual responsibility. Despite what some would have us believe, success is not built on resentment and fears.", "author": "Susana Martinez"},
    {"quote": "I practice my saxophone three hours a day. I’m not saying I’m particularly special, but if you do something three hours a day for forty years, you get pretty good at it.", "author": "Kenny G"},
    {"quote": "Smooth seas do not make skillful sailors.", "author": "African Proverb"},
    {"quote": "I know the price of success: dedication, hard work and an unremitting devotion to the things you want to see happen.", "author": "Frank Lloyd Wright"},
    {"quote": "I think one day you’ll find that you’re the hero you’ve been looking for.", "author": "Jimmy Stewart"},
    {"quote": "If all I do in my life is soothe someone’s spirit with a song, then let me do that and I’m happy.", "author": "Gladys Knight"},
    {"quote": "Life becomes easier when you learn to accept the apology you never got.", "author": "Robert Brault"},
    {"quote": "There are times in all of our lives when a reliance on gut or intuition just seems more appropriate, when a particular course of action just feels right. And, interestingly, I’ve discovered it’s in facing life’s most important decisions that intuition seems the most indispensable.", "author": "Tim Cook"},
    {"quote": "All labor that uplifts humanity has dignity and importance.", "author": "Martin Luther King Jr."},
    {"quote": "You may think using Google’s great, but I still think it’s terrible.", "author": "Larry Page"},
    {"quote": "It’s tough to get out of bed to do roadwork at 5 a.m. when you’ve been sleeping in silk pajamas.", "author": "Marvin Hagler"},
    {"quote": "There is no security on the Earth, there is only opportunity.", "author": "Douglas MacArthur"},
    {"quote": "Everyone’s like, 'overnight sensation.' It’s not overnight. It’s years of hard work.", "author": "Margot Robbie"},
    {"quote": "The worth of a life is not determined by a single failure or a solitary success.", "author": "Kevin Kline"},
    {"quote": "Only the weak are cruel. Gentleness can only be expected from the strong.", "author": "Leo Buscaglia"},
    {"quote": "For small creatures such as we, the vastness is bearable only through love.", "author": "Carl Sagan"},
    {"quote": "Build something 100 people love, not something 1 million people kind of like.", "author": "Brian Chesky"},
    {"quote": "Once you replace negative thoughts with positive ones, you’ll start having positive results.", "author": "Willie Nelson"},
    {"quote": "Don’t write what you think people want to read. Find your voice and write about what’s in your heart.", "author": "Quentin Tarantino"},
    {"quote": "Life is what we make it, always has been, always will be.", "author": "Grandma Moses"},
    {"quote": "There is overwhelming evidence that the higher the level of self-esteem, the more likely one will be to treat others with respect, kindness, and generosity.", "author": "Nathaniel Branden"},
    {"quote": "It’s a good place when all you have is hope and not expectations.", "author": "Danny Boyle"},
    {"quote": "Good things come to obsessive compulsives who fixate.", "author": "Kieran Culkin"},
    {"quote": "It is easier to build strong children than to repair broken men.", "author": "Frederick Douglass"},
    {"quote": "You can’t be afraid of what people are going to say, because you’re never going to make everyone happy.", "author": "Selena Gomez"},
    {"quote": "Waking up in truth is so much better than living in a lie.", "author": "Idris Elba"},
    {"quote": "Instead of looking at the past, I put myself ahead 20 years and try to look at what I need to do now in order to get there then.", "author": "Diana Ross"},
    {"quote": "People seldom do what they believe in. They do what is convenient, and then repent.", "author": "Bob Dylan"},
    {"quote": "Anything in life worth having is worth working for.", "author": "Andrew Carnegie"},
    {"quote": "Life is short, and the world is wide.", "author": "Simon Raven"},
    {"quote": "I felt that one had better die fighting against injustice than to die like a dog or rat in a trap. I had already determined to sell my life as dearly as possible if attacked. I felt if I could take one lyncher with me, this would even up the score a little bit.", "author": "Ida B. Wells"},
    {"quote": "There are two ways of spreading light: to be the candle or the mirror that reflects it.", "author": "Edith Wharton"},
    {"quote": "How old would you be if you didn’t know how old you are?", "author": "Satchel Paige"},
    {"quote": "When you find an idea that you just can’t stop thinking about, that’s probably a good one to pursue.", "author": "Josh James"},
    {"quote": "We each come by the gifts we have to offer by an infinite series of influences and lucky breaks we can never fully understand.", "author": "MacKenzie Scott"},
    {"quote": "Everyone thinks of changing the world, but no one thinks of changing himself.", "author": "Leo Tolstoy"},
    {"quote": "Economics is like the Dutch language. I’m told it makes sense, but I have my doubts.", "author": "John Oliver"},
    {"quote": "Ultimately, you just have one life. You never know unless you try. And you never get anywhere unless you ask.", "author": "Kate Winslet"},
    {"quote": "We are all ordinary. We are all boring. We are all spectacular. We are all shy. We are all bold. We are all heroes. We are all helpless. It just depends on the day.", "author": "Brad Meltzer"},
    {"quote": "Think of how stupid the average person is, and realize half of them are stupider than that.", "author": "George Carlin"},
    {"quote": "Some of the world’s greatest feats were accomplished by people not smart enough to know they were impossible.", "author": "Doug Larson"},
    {"quote": "Take wrong turns. Talk to strangers. Open unmarked doors. And if you see a group of people in a field, go find out what they are doing. Do things without always knowing how they’ll turn out.", "author": "Randall Munroe"},
    {"quote": "I’m intimidated by the fear of being average.", "author": "Taylor Swift"},
    {"quote": "Always be a first-rate version of yourself instead of a second-rate version of somebody else.", "author": "Judy Garland"},
    {"quote": "The history of the world is the history of a few people who had faith in themselves.", "author": "Swami Vivekananda"},
    {"quote": "The one thing you’re most reluctant to tell. That’s where the comedy is.", "author": "Mike Birbiglia"},
    {"quote": "Doubt is a killer. You just have to know who you are and what you stand for.", "author": "Jennifer Lopez"},
    {"quote": "Basically, the first half of life is writing the text, and the second half is writing the commentary on that text.", "author": "Richard Rohr"},
    {"quote": "Great artists steal is about finding inspiration in the work of others, then using it as a starting point for original creative output.", "author": "Pablo Picasso"},
    {"quote": "Don’t count the days, make the days count.", "author": "Muhammad Ali"},
    {"quote": "You must not only aim right, but draw the bow with all your might.", "author": "Henry David Thoreau"},
    {"quote": "Your days are numbered. Use them to throw open the windows of your soul to the sun. If you do not, the sun will soon set, and you with it.", "author": "Marcus Aurelius"},
    {"quote": "I have already lost touch with a couple of people I used to be.", "author": "Joan Didion"},
    {"quote": "Fear of looking stupid is the No. 1 killer of dreams. The worst part? The people who make you feel stupid are usually the ones least qualified to judge someone else’s life.", "author": "Anthony Moore"},
    {"quote": "I’ve grown most not from victories but from setbacks. If winning is God’s reward, then losing is how he teaches us.", "author": "Serena Williams"},
    {"quote": "Life is 10 percent what happens to me and 90 percent of how I react to it.", "author": "Charles R. Swindoll"},
    {"quote": "A successful man is one who can lay a firm foundation with the bricks others have thrown at him.", "author": "David Brinkley"},
    {"quote": "I don’t know what the future may hold, but I know who holds the future.", "author": "Ralph Abernathy"},
    {"quote": "People always fall in love with the most perfect aspects of each other’s personalities. Who wouldn’t? Anybody can love the most wonderful parts of another person. But that’s not the clever trick. The really clever trick is this: Can you accept the flaws?", "author": "Elizabeth Gilbert"},
    {"quote": "Being an optimist after you’ve got the very thing you want doesn’t count.", "author": "Ken Hubbard"},
    {"quote": "I can say the willingness to get dirty has always defined us as a nation, and it’s a hallmark of hard work and a hallmark of fun, and dirt is not the enemy.", "author": "Mike Rowe"},
    {"quote": "I’ll tell you what bravery really is. Bravery is just determination to do a job that you know has to be done.", "author": "Audie Murphy"},
    {"quote": "Always look for the fool in the deal. If you don’t find one, it’s you.", "author": "Mark Cuban"},
    {"quote": "If everyone is thinking alike, then somebody isn’t thinking.", "author": "George S. Patton"},
    {"quote": "No matter what people tell you, words and ideas can change the world.", "author": "Robin Williams"},
    {"quote": "Philosophy is like trying to open a safe with a combination lock: each little adjustment of the dials seems to achieve nothing, only when everything is in place does the door open.", "author": "Ludwig Wittgenstein"},
    {"quote": "I am not a product of my circumstances. I am a product of my decisions.", "author": "Stephen Covey"},
    {"quote": "Victory has a hundred fathers and defeat is an orphan.", "author": "John F. Kennedy"},
    {"quote": "If you hear the dogs, keep going. If you see the torches in the woods, keep going. If there’s shouting after you, keep going. Don’t ever stop. Keep going. If you want a taste of freedom, keep going.", "author": "Harriet Tubman"},
    {"quote": "Art, in itself, is an attempt to bring order out of chaos.", "author": "Stephen Sondheim"},
    {"quote": "Reality is created by the mind; we can change our reality by changing our mind.", "author": "Plato"},
    {"quote": "Grant me courage to serve others; for in service there is true life.", "author": "Cesar Chavez"},
    {"quote": "Anyone with two tunics should share with him who has none.", "author": "John the Baptist"},
    {"quote": "A pessimist sees the difficulty in every opportunity; an optimist sees the opportunity in every difficulty.", "author": "Winston Churchill"},
    {"quote": "What I’ve learned from running is that the time to push hard is when you’re hurting like crazy and you want to give up. Success is often just around the corner.", "author": "James Dyson"},
    {"quote": "Do you really want to look back on your life and see how wonderful it could have been had you not been afraid to live it?", "author": "Caroline Myss"},
    {"quote": "The secret of a happy marriage is finding the right person. You know they’re right if you love to be with them all the time.", "author": "Julia Child"},
    {"quote": "Flaming enthusiasm, backed by horse-sense and persistence, is the quality that most frequently makes for success.", "author": "Dale Carnegie"},
    {"quote": "God loves us beyond comprehension, and we cannot diminish God’s love for us.", "author": "Peter Kreeft"},
    {"quote": "What gets celebrated gets replicated.", "author": "Bradley Cooper"},
    {"quote": "The best way to predict the future is to invent it.", "author": "Alan Kay"},
    {"quote": "Everyone you meet in life is fighting a battle you know nothing about.", "author": "Wendy Mass"},
    {"quote": "If you look around the room, and you’re the smartest person in the room, you’re in the wrong room.", "author": "Lorne Michaels"},
    {"quote": "Being polite and grateful will make people more inclined to help you. And if people are willing to help you, you may accidentally get something you want.", "author": "Jason Sudeikis"},
    {"quote": "If people knew how hard I worked to achieve my mastery, it wouldn’t seem so wonderful after all.", "author": "Michelangelo"},
    {"quote": "If you want to change who you are, you have to change what you do.", "author": "Jude Law"},
    {"quote": "The best time to plant a tree was 20 years ago. The second best time is now.", "author": "Chinese Proverb"},
    {"quote": "Bridge the age gap. For younger people, find a way to spend time with older people. For the more silver-haired among us, I’m telling you: Find a few things the young kids are into — music, tech, sports — and check them out.", "author": "Mike Erwin"},
    {"quote": "I’m not afraid of storms, for I’m learning how to sail my ship.", "author": "Louisa May Alcott"},
    {"quote": "Today a reader, tomorrow a leader.", "author": "Margaret Fuller"},
    {"quote": "Freedom lies in being bold.", "author": "Robert Frost"},
    {"quote": "I will take the subway and look at certain women and think 'God, that woman’s story will never be told. How come that lady doesn’t get a movie about her?'", "author": "Natasha Lyonne"},
    {"quote": "If you focus on results you’ll never change. If you focus on change, you’ll get results.", "author": "Jack Dixon"},
    {"quote": "Empty your mind, be formless. Shapeless, like water. If you put water into a cup, it becomes the cup. You put water into a bottle and it becomes the bottle. You put it in a teapot it becomes the teapot. Now, water can flow or it can crash. Be water, my friend.", "author": "Bruce Lee"},
    {"quote": "Complexity kills. It sucks the life out of developers, it makes products difficult to plan, build and test, it introduces security challenges, and it causes end-user and administrator frustration.", "author": "Ray Ozzie"},
    {"quote": "When one door closes another door opens; but we so often look so long and so regretfully upon the closed door, that we do not see the ones which open for us.", "author": "Alexander Graham Bell"},
    {"quote": "The greatest lesson that I learned in all of this is that you have to start. Start now, start here, and start small. Keep it simple.", "author": "Jack Dorsey"},
    {"quote": "The crisis of today is the joke of tomorrow.", "author": "H.G. Wells"},
    {"quote": "Either America will destroy ignorance or ignorance will destroy the United States.", "author": "W. E. B. Du Bois"},
    {"quote": "It would be wonderful if I can inspire others, who are struggling to realize their dreams, to say: If this country kid could do it, let me keep slogging away.", "author": "Douglas Engelbart"},
    {"quote": "Everything you’ve ever wanted is on the other side of fear.", "author": "George Addair"},
    {"quote": "Sometimes you can only find heaven by slowly backing away from hell.", "author": "Carrie Fisher"},
    {"quote": "I’ve got to give props to the Jesuit priests.", "author": "Neil deGrasse Tyson"},
    {"quote": "If God took the trouble to tell us eight hundred times to be glad and rejoice, He must want us to do it!", "author": "Eleanor H. Porter"},
    {"quote": "That’s the best part of the whole thing, is the people that we’ve met along the way. We’ve met some wonderful, wonderful people and we wouldn’t have otherwise.", "author": "Pearl Dion"},
    {"quote": "Conditions are never perfect. 'Someday' is a disease that will take your dreams to the grave with you. If it’s important to you and you want to do it 'eventually,' just do it and correct course along the way.", "author": "Tim Ferriss"},
    {"quote": "Whatever you do, don’t wake up at 65 years old and think about what you should have done with your life.", "author": "George Clooney"},
    {"quote": "My soul is that of a drummer. I didn’t do it to become rich and famous. I did it because it was the love of my life.", "author": "Ringo Starr"},
    {"quote": "Just keep going. Everybody gets better if they keep at it.", "author": "Ted Williams"},
    {"quote": "There can be no greater gift than that of giving one’s time and energy to help others without expecting anything in return.", "author": "Nelson Mandela"},
    {"quote": "Good luck has its storms.", "author": "George Lucas"},
    {"quote": "Faith moves mountains, but you have to keep pushing while you’re praying.", "author": "Mason Cooley"},
    {"quote": "No failure means no risk, which means nothing new.", "author": "Richard Branson"},
    {"quote": "I’m a big believer in the power of inexperience. It was the greatest asset I had when I started TFA. If I had known at the outset how hard it was going to be, I might never have started.", "author": "Wendy Kopp"},
    {"quote": "Who sows virtue reaps honor.", "author": "Leonardo da Vinci"},
    {"quote": "So often, people are working hard at the wrong thing. Working on the right thing is probably more important than working hard.", "author": "Caterina Fake"},
    {"quote": "I think of doing a series as very hard work. But then I’ve talked to coal miners, and that’s really hard work.", "author": "William Shatner"},
    {"quote": "Life is a daring adventure or it is nothing at all.", "author": "Helen Keller"},
    {"quote": "Whenever you read a good book, somewhere in the world a door opens to allow in more light.", "author": "Vera Nazarian"},
    {"quote": "To see we must forget the name of the thing we are looking at.", "author": "Claude Monet"},
    {"quote": "I didn’t like the idea of being foolish, but I learned pretty soon that it was essential to fail and be foolish.", "author": "Daniel Day-Lewis"},
    {"quote": "I hate that word: lucky. It cheapens a lot of hard work.", "author": "Peter Dinklage"},
    {"quote": "Even when I was close to defeat I rose to my feet.", "author": "Dr. Dre"},
    {"quote": "Happiness is an inside job.", "author": "William Arthur Ward"},
    {"quote": "I was literally just doing my job.", "author": "Stanislav Petrov"},
    {"quote": "All good ideas start out as bad ideas, that’s why it takes so long.", "author": "Steven Spielberg"},
    {"quote": "The world has never had a good definition of the word liberty, and the American people, just now, are much in want of one.", "author": "Abraham Lincoln"},
    {"quote": "I wanted a perfect ending. Now I’ve learned, the hard way, that some poems don’t rhyme, and some stories don’t have a clear beginning, middle and end.", "author": "Gilda Radner"},
    {"quote": "Giving up smoking is the easiest thing in the world. I know because I’ve done it thousands of times.", "author": "Mark Twain"},
    {"quote": "Only eyes washed by tears can see clearly.", "author": "Louis Mann"},
    {"quote": "You have to learn the rules to be able to know how to break them.", "author": "Keira Knightley"},
    {"quote": "The meaning of life is to find your gift. The purpose of life is to give it away.", "author": "Pablo Picasso"},
    {"quote": "You are never too old to set another goal or to dream a new dream.", "author": "Les Brown"},
    {"quote": "The essence of strategy is choosing what not to do.", "author": "Michael Porter"},
    {"quote": "Let me tell you the secret that has led me to my goals: my strength lies solely in my tenacity.", "author": "Louis Pasteur"},
    {"quote": "Your employees come first. And if you treat your employees right, guess what? Your customers come back.", "author": "Herb Kelleher"},
    {"quote": "Success isn’t determined by how many times you win, but by how you play the week after you lose.", "author": "Pele"},
    {"quote": "I am happy because I’m grateful. I choose to be grateful. That gratitude allows me to be happy.", "author": "Will Arnett"},
    {"quote": "The true secret of happiness lies in taking a genuine interest in all the details of daily life.", "author": "William Morris"},
    {"quote": "I would rather die of passion than of boredom.", "author": "Vincent van Gogh"},
    {"quote": "The impossible exists only until we find a way to make it possible.", "author": "Mike Horn"},
    {"quote": "Boredom is a lack of crazy. It’s a lack of creativity. Invention. Innovation. If you’re bored, blame yourself.", "author": "Katelyn S. Irons"},
    {"quote": "The greatest danger in times of turbulence is not the turbulence; it is to act with yesterday’s logic.", "author": "Peter Drucker"},
    {"quote": "Never let anyone define you. You are the only person who defines you. No one can speak for you. Only you speak for you. You are your only voice.", "author": "Terry Crews"},
    {"quote": "Be so good they can’t ignore you.", "author": "Steve Martin"},
    {"quote": "Nothing in all the world is more dangerous than sincere ignorance and conscientious stupidity.", "author": "Martin Luther King Jr."},
    {"quote": "The only way to win is to learn faster than anyone else.", "author": "Eric Ries"},
    {"quote": "God doesn’t require us to succeed, he only requires that you try.", "author": "Mother Teresa"},
    {"quote": "May I never be complete. May I never be content. May I never be perfect.", "author": "Chuck Palahniuk"},
    {"quote": "Instead of wondering when your next vacation is, maybe you should set up a life you don’t need to escape from.", "author": "Seth Godin"},
    {"quote": "The greatest test of courage on earth is to bear defeat without losing heart.", "author": "Robert Green Ingersoll"},
    {"quote": "It isn’t hard to be good from time to time in sports. What is tough, is being good every day.", "author": "Willie Mays"},
    {"quote": "Death is very likely the single best invention of life. It’s life’s change agent; it clears out the old to make way for the new. Right now, the new is you. But someday, not too long from now, you will gradually become the old and be cleared away. Sorry to be so dramatic, but it’s quite true. Your time is limited, so don’t waste it living someone else’s life.", "author": "Steve Jobs"},
    {"quote": "Have no fear of perfection. You’ll never reach it.", "author": "Salvador Dalí"},
    {"quote": "The most common way people give up their power is by thinking they don’t have any.", "author": "Alice Walker"},
    {"quote": "The person who agrees with you 80 percent of the time is an 80 percent friend, not a 20 percent enemy.", "author": "Ronald Reagan"},
    {"quote": "The thing about smart people is that they seem like crazy people to dumb people.", "author": "Stephen Hawking"},
    {"quote": "People have confused playing devil’s advocate with being intelligent.", "author": "Cecily Strong"},
    {"quote": "Winning is not everything, but wanting to win is.", "author": "Vince Lombardi"},
    {"quote": "The minute you start caring about what other people think, is the minute you stop being yourself.", "author": "Meryl Streep"},
    {"quote": "Optimism is the one quality more associated with success and happiness than any other.", "author": "Brian Tracy"},
    {"quote": "People who say it cannot be done should not interrupt those who are doing it.", "author": "George Bernard Shaw"},
    {"quote": "My only goal is to stay focused on my craft and make sure my life is as sharp as it can be to attack any character that is given to me.", "author": "Michael K. Williams"},
    {"quote": "If you’re ever thinking, Oh, but I’m a waste of space and I’m a burden, remember: that also describes the Grand Canyon. Why don’t you have friends and family take pictures of you from a safe distance? Revel in your majestic profile?", "author": "Maria Bamford"},
    {"quote": "If everybody loves you, something is wrong. Find at least one enemy to keep you alert.", "author": "Paulo Coelho"},
    {"quote": "The world is more malleable than you think and it’s waiting for you to hammer it into shape.", "author": "Bono"},
    {"quote": "Yes, I am a dreamer. For a dreamer is one who can find his way by moonlight, and see the dawn before the rest of the world.", "author": "Oscar Wilde"},
    {"quote": "Always make a total effort, even when the odds are against you.", "author": "Arnold Palmer"},
    {"quote": "Life doesn’t run away from nobody. Life runs at people.", "author": "Joe Frazier"},
    {"quote": "The last 10 percent it takes to launch something takes as much energy as the first 90 percent.", "author": "Rob Kalin"},
    {"quote": "Don’t let life discourage you; everyone who got where he is had to begin where he was.", "author": "Richard L. Evans"},
    {"quote": "Greatness is a lot of small things done well. Day after day, workout after workout, obedience after obedience, day after day.", "author": "Ray Lewis"},
    {"quote": "Risk more than others think is safe. Dream more than others think is practical.", "author": "Howard Schultz"},
    {"quote": "Next time you think you are important, try ordering somebody else’s dog around.", "author": "Will Rogers"},
    {"quote": "I made a resolve then that I was going to amount to something if I could. And no hours, nor amount of labor, nor amount of money would deter me from giving the best that there was in me. And I have done that ever since, and I win by it. I know.", "author": "Colonel Harland Sanders"},
    {"quote": "If you see a bandwagon, it’s too late.", "author": "James Goldsmith"},
    {"quote": "Everyone has a plan ’til they get punched in the mouth.", "author": "Mike Tyson"},
    {"quote": "I’ve missed more than 9000 shots in my career. I’ve lost almost 300 games. 26 times, I’ve been trusted to take the game winning shot and missed. I’ve failed over and over and over again in my life. And that is why I succeed.", "author": "Michael Jordan"},
    {"quote": "One, don’t believe everything that’s written about you. Two, don’t pick up too many checks.", "author": "Babe Ruth"},
    {"quote": "Before you speak, run this through your head: Is what I’m about to say true? Is it helpful? Is it inspiring? Is it necessary? Is it kind? If you cannot answer yes to these questions, then don’t say it, don’t tweet it, don’t write it.", "author": "Beret Guidera"},
    {"quote": "You can and should set your own limits and clearly articulate them. This takes courage, but it is also liberating and empowering, and often earns you new respect.", "author": "Rosalind Brewer"},
    {"quote": "Every vision is a joke until the first man accomplishes it; once realized, it becomes commonplace.", "author": "Robert Goddard"},
    {"quote": "Don’t be afraid your life will end; be afraid that it will never begin.", "author": "Grace Hansen"},
    {"quote": "When you meet somebody for the first time, you’re not meeting them. You’re meeting their representative.", "author": "Chris Rock"},
    {"quote": "Not everything that can be counted counts, and not everything that counts can be counted.", "author": "William Bruce Cameron"},
    {"quote": "We always honor our people when they die; we’ve got to honor them while we’re still alive.", "author": "Biz Markie"},
    {"quote": "Live your life as an exclamation rather than an explanation.", "author": "Isaac Newton"},
    {"quote": "It’s easy to do nothing, but your heart breaks a little more every time you do.", "author": "Mark Ruffalo"},
    {"quote": "Pressure is a privilege. It only comes to those who earn it.", "author": "Billie Jean King"},
    {"quote": "There will come a time when you believe everything is finished. That will be the beginning.", "author": "Louis L’Amour"},
    {"quote": "The truth is, everyone is going to hurt you. You just got to find the ones worth suffering for.", "author": "Bob Marley"},
    {"quote": "Give me a stock clerk with a goal, and I will give you a man who will make history. Give me a man without a goal, and I will give you a stock clerk.", "author": "James Cash Penney"},
    {"quote": "I shall never pay a dollar of your unjust penalty.", "author": "Susan B. Anthony"},
    {"quote": "My first job was washing dishes in the basement of a nursing home for $2.10 an hour, and I learned as much about the value of hard work there as I ever did later.", "author": "Douglas Preston"},
    {"quote": "Understand well as I may, my comprehension can only be an infinitesimal fraction of all I want to understand.", "author": "Ada Lovelace"},
    {"quote": "When you are not willing to fully receive, you are training the universe not to give to you! It’s simple: if you aren’t willing to receive your share, it will go to someone else who is.", "author": "T. Harv Eker"},
    {"quote": "You’re going to fall down, but the world doesn’t care how many times you fall down, as long as it’s one fewer than the numbers of times you get back up.", "author": "Aaron Sorkin"},
    {"quote": "You do this because you like it, you think what you’re making is beautiful. And if you think it’s beautiful, maybe they think it’s beautiful.", "author": "Lou Reed"},
    {"quote": "We are less bored than our ancestors were, but we are more afraid of boredom.", "author": "Bertrand Russell"},
    {"quote": "Luck? I don’t know anything about luck. I’ve never banked on it, and I’m afraid of people who do. Luck to me is something else: hard work, and realizing what is opportunity and what isn’t.", "author": "Lucille Ball"},
    {"quote": "Don’t aspire to make a living, aspire to make a difference.", "author": "Denzel Washington"},
    {"quote": "It’s good to learn from your mistakes. It’s better to learn from other people’s mistakes.", "author": "Warren Buffett"},
    {"quote": "Every man dies. Not every man really lives.", "author": "William Wallace"},
    {"quote": "I feel like if it’s not scaring you, you’re doing it wrong.", "author": "Anna Kendrick"},
    {"quote": "You don’t become what you want, you become what you believe.", "author": "Oprah Winfrey"},
    {"quote": "There is no element of genius without some form of madness.", "author": "Aristotle"},
    {"quote": "Sometimes you have to wander a bit, and do what you don’t want to in order to figure out what it is you’re supposed to do.", "author": "Larry David"},
    {"quote": "Life always offers you a second chance. It is called tomorrow.", "author": "Dylan Thomas"},
    {"quote": "To scale, do things that don’t scale.", "author": "Reid Hoffman"},
    {"quote": "Normal is not something to aspire to, it’s something to get away from.", "author": "Jodie Foster"},
    {"quote": "Sometimes your joy is the source of your smile, but sometimes your smile can be the source of your joy.", "author": "Thich Nhat Hanh"},
    {"quote": "Men give me credit for some genius. All the genius I have lies in this; when I have a subject in hand, I study it profoundly. Day and night it is before me. My mind becomes pervaded with it. Then the effort that I have made is what people are pleased to call the fruit of genius. It is the fruit of labor and thought.", "author": "Alexander Hamilton"},
    {"quote": "Time is life itself, and life resides in the human heart.", "author": "Michael Ende"},
    {"quote": "The big money is not in the buying and selling … but in the waiting.", "author": "Charlie Munger"},
    {"quote": "Gratitude is not only the greatest of virtues, but the parent of all the others.", "author": "Marcus Tullius Cicero"},
    {"quote": "Someone once said, 'Adversity introduces a man to himself.' For some reason, that’s scary, but most people discover that adversity does make them stronger.", "author": "Max Cleland"},
    {"quote": "I can’t tell you which one is right. But I can tell you which one is more fun.", "author": "Phil Knight"},
    {"quote": "The lessons aren’t about wealth or fame or working harder and harder. The clearest message that we get from this 75-year study is this: Good relationships keep us happier and healthier. Period.", "author": "Robert Waldinger"},
    {"quote": "I put instant coffee in a microwave oven and almost went back in time.", "author": "Steven Wright"},
    {"quote": "The best way out is always through.", "author": "Robert Frost"},
    {"quote": "If you want to lift yourself up, lift up someone else.", "author": "Booker T. Washington"},
    {"quote": "Still and all, why bother? Here’s my answer. …", "author": "Kurt Vonnegut"},
    {"quote": "In every good marriage, it helps sometimes to be a little deaf.", "author": "Ruth Bader Ginsburg"},
    {"quote": "People think I’m an overnight success. No. It’s just that you all found me overnight.", "author": "Leslie Jones"},
    {"quote": "To bring about change, you must not be afraid to take the first step. We will fail when we fail to try.", "author": "Rosa Parks"},
    {"quote": "If you think you are too small to make a difference, try sleeping with a mosquito.", "author": "Dalai Lama"},
    {"quote": "There is only one boss: the customer. And he can fire everybody in the company, from the chairman on down, simply by spending his money somewhere else.", "author": "Sam Walton"},
    {"quote": "I always want to say to people who want to be rich and famous: 'Try being rich first.' See if that doesn’t cover most of it.", "author": "Bill Murray"},
    {"quote": "We don’t want to suffer. We don’t want to feel discomfort. So the whole time, we’re living our lives in a very comfortable area. There’s no growth in that.", "author": "David Goggins"},
    {"quote": "It’s better for people to miss you than to have seen too much of you.", "author": "Edward Norton"},
    {"quote": "Forget about style; worry about results.", "author": "Bobby Orr"},
    {"quote": "St. Francis of Assisi taught me that there is a wound in the Creation and that the greatest use we could make of our lives was to ask to be made a healer of it.", "author": "Alan Paton"},
    {"quote": "My motto was always to keep swinging. Whether I was in a slump or feeling badly or having trouble off the field, the only thing to do was keep swinging.", "author": "Hank Aaron"},
    {"quote": "Developing a good work ethic is key. Apply yourself at whatever you do, whether you’re a janitor or taking your first summer job, because that work ethic will be reflected in everything you do in life.", "author": "Tyler Perry"},
    {"quote": "The road to success is not easy to navigate, but with hard work, drive, and passion, it’s possible to achieve the American dream.", "author": "Tommy Hilfiger"},
    {"quote": "I don’t like to gamble, but if there’s one thing I’m willing to bet on, it’s myself.", "author": "Beyoncé"},
    {"quote": "Nobody in life gets exactly what they thought they were going to get. But if you work really hard and you’re kind, amazing things will happen.", "author": "Conan O’Brien"},
    {"quote": "Pray as though everything depended on God. Work as though everything depended on you.", "author": "Saint Augustine"},
    {"quote": "If you don’t fall how are you going to know what getting up is like.", "author": "Stephen Curry"},
    {"quote": "Frankly, it’s time for a new generation of leaders.", "author": "Mitt Romney"},
    {"quote": "To be a Christian means to forgive the inexcusable because God has forgiven the inexcusable in you.", "author": "C. S. Lewis"},
    {"quote": "I always prefer to believe the best of everybody, it saves so much trouble.", "author": "Rudyard Kipling"},
    {"quote": "This is it. This is life, the one you get.", "author": "Jeff Barry"},
    {"quote": "Greatness is not measured by what you build, but by what you inspire others to create.","author": "Raul M. Uñate"}
]
